@@ -9,7 +9,7 @@ import sys
 import time
 from typing import Iterable, Set, Tuple
 import os
-from cryptography.hazmat.primitives.ciphers import Cipher,algorithms
+from cryptography.hazmat.primitives.ciphers import Cipher, algorithms
 import subprocess
 import sys
 from KeyisBClient import Url
@@ -126,12 +126,7 @@ def _kill_process_by_port(port: int):
 
 
 
-
-def _sign(k:bytes)->bytes:nonce=os.urandom(16);m=b"keyisb-vm-host-"+os.urandom(32);return nonce+Cipher(algorithms.ChaCha20(k[:32],nonce),None).encryptor().update(m)
-def _verify(k:bytes,s:bytes)->bool:nonce,ct=s[:16],s[16:];return Cipher(algorithms.ChaCha20(k[:32],nonce),None).decryptor().update(ct).startswith(b"keyisb-vm-host-")
-
-
-
+from KeyisBTools.cryptography.sign import s1
 
 import socket
 
@@ -153,6 +148,31 @@ def is_port_in_use(port: int, proto: str = "tcp") -> bool:
     return False
 
 
+class AsyncLogWriter:
+    def __init__(self, path: str, flush_interval: int = 3):
+        self.file = open(path, "w+")
+        self.flush_interval = flush_interval
+        self._stop = False
+        self._start = False
+
+    async def _flusher(self):
+        while not self._stop:
+            await asyncio.sleep(self.flush_interval)
+            self.file.flush()
+
+    def write(self, msg: str):
+        self.file.write(msg + "\n")
+
+        if not self._start:
+            asyncio.create_task(self._flusher())
+            self._start = True
+
+    def close(self):
+        self._stop = True
+        self.file.flush()
+        self.file.close()
+
+
 class App():
     def __init__(self):
         self._app = _App()
@@ -187,7 +207,8 @@ class App():
             raise Exception('Путь не найден')
 
     def writeLog(self, domain: str, msg: str):
-        file: Optional[TextIOWrapper] = self._servers_start_files[domain].get('_log_file')
+        print(domain, msg)
+        file: Optional[AsyncLogWriter] = self._servers_start_files[domain].get('_log_file')
         if file is not None:
             file.write(msg)
 
@@ -228,7 +249,7 @@ class App():
 
         
         if log_path is not None:
-            file = open(log_path, 'w+')
+            file = AsyncLogWriter(log_path)
             
             self._servers_start_files[domain]["_log_file"] = file
 
@@ -258,8 +279,8 @@ class App():
             
             cert_path = server['cert_path']
             key_path = server['key_path']
-
-            if cert_path is None or key_path is None:
+            
+            if vm_host and (cert_path is None or key_path is None):
                 raise Exception('Не указаны сертификаты')
             
             if not os.path.isfile(path):
@@ -288,11 +309,11 @@ class App():
                 else:
                     argv = [
                         'gn:vm-host:start',
-                        domain,
-                        port,
-                        cert_path,
-                        key_path,
-                        host
+                        str(domain),
+                        str(port),
+                        str(cert_path),
+                        str(key_path),
+                        str(host)
                     ]
 
                 self.writeLog(domain, 'Server starting...')
@@ -317,8 +338,8 @@ class App():
 
                         self.writeLog(domain, f"{prefix}: {line.strip()}")
 
-                asyncio.create_task(log_stream(proc.stdout, "STDOUT"))
-                asyncio.create_task(log_stream(proc.stderr, "STDERR"))
+                asyncio.create_task(log_stream(proc.stdout, ""))
+                asyncio.create_task(log_stream(proc.stderr, "ERR"))
 
                 try:
                     returncode = await asyncio.to_thread(proc.wait, 3)
@@ -420,24 +441,27 @@ class App():
             raise ValueError(f"No server start file found with domain: {domain}")
 
     def run(self,
-            host,
+            domain,
             port,
             cert_path: str,
             key_path: str,
             *,
+            host: str = '0.0.0.0',
             idle_timeout: float = 20.0,
             wait: bool = True
             ):
         
 
         self._app.run(
-            host=host,
+            domain=domain,
             port=port,
             cert_path=cert_path,
             key_path=key_path,
+
+            host=host,
             idle_timeout=idle_timeout,
             wait=wait,
-            run=self.startLikeRun
+            run=self.startLikeRun,
         )
 
 
@@ -450,7 +474,7 @@ class App():
         if sign is None:
             return False
 
-        return _verify(self._access_key.encode(), sign)
+        return s1.verify(self._access_key.encode(), sign, 60)
 
     def __add_routes(self):
         @self._app.route('POST', '/ping')
